@@ -1,5 +1,25 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
+#
+# Copyright 2021 The NiPreps Developers <nipreps@gmail.com>
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# We support and encourage derived works from this project, please read
+# about our expectations at
+#
+#     https://www.nipreps.org/community/licensing/
+#
 """Anatomical reference preprocessing workflows."""
 from pkg_resources import resource_filename as pkgr
 
@@ -20,7 +40,8 @@ from niworkflows.interfaces.freesurfer import (
     StructuralReference,
     PatchedLTAConvert as LTAConvert,
 )
-from niworkflows.interfaces.images import TemplateDimensions, Conform, ValidateImage
+from niworkflows.interfaces.header import ValidateImage
+from niworkflows.interfaces.images import TemplateDimensions, Conform
 from niworkflows.interfaces.nitransforms import ConcatenateXFMs
 from niworkflows.interfaces.utility import KeySelect
 from niworkflows.utils.misc import fix_multi_T1w_source_name, add_suffix
@@ -31,25 +52,25 @@ from .norm import init_anat_norm_wf
 from .outputs import init_anat_reports_wf, init_anat_derivatives_wf
 from .surfaces import init_surface_recon_wf
 
-LOGGER = logging.getLogger('nipype.workflow')
+LOGGER = logging.getLogger("nipype.workflow")
 
 
 def init_anat_preproc_wf(
-        *,
-        bids_root,
-        freesurfer,
-        hires,
-        longitudinal,
-        t1w,
-        omp_nthreads,
-        output_dir,
-        skull_strip_mode,
-        skull_strip_template,
-        spaces,
-        debug=False,
-        existing_derivatives=None,
-        name='anat_preproc_wf',
-        skull_strip_fixed_seed=False,
+    *,
+    bids_root,
+    freesurfer,
+    hires,
+    longitudinal,
+    t1w,
+    omp_nthreads,
+    output_dir,
+    skull_strip_mode,
+    skull_strip_template,
+    spaces,
+    debug=False,
+    existing_derivatives=None,
+    name="anat_preproc_wf",
+    skull_strip_fixed_seed=False,
 ):
     """
     Stage the anatomical preprocessing steps of *sMRIPrep*.
@@ -191,49 +212,69 @@ def init_anat_preproc_wf(
 : """
     desc += """\
 A total of {num_t1w} T1-weighted (T1w) images were found within the input
-BIDS dataset.""".format(num_t1w=num_t1w)
+BIDS dataset.""".format(
+        num_t1w=num_t1w
+    )
 
     inputnode = pe.Node(
-        niu.IdentityInterface(fields=['t1w', 't2w', 'roi', 'flair', 'subjects_dir', 'subject_id']),
-        name='inputnode')
+        niu.IdentityInterface(
+            fields=["t1w", "t2w", "roi", "flair", "subjects_dir", "subject_id"]
+        ),
+        name="inputnode",
+    )
 
-    outputnode = pe.Node(niu.IdentityInterface(
-        fields=['template', 'subjects_dir', 'subject_id'] + get_outputnode_spec()),
-        name='outputnode')
+    outputnode = pe.Node(
+        niu.IdentityInterface(
+            fields=["template", "subjects_dir", "subject_id"] + get_outputnode_spec()
+        ),
+        name="outputnode",
+    )
 
     # Connect reportlets workflows
     anat_reports_wf = init_anat_reports_wf(
         freesurfer=freesurfer,
         output_dir=output_dir,
     )
+    # fmt:off
     workflow.connect([
         (outputnode, anat_reports_wf, [
             ('t1w_preproc', 'inputnode.t1w_preproc'),
             ('t1w_mask', 'inputnode.t1w_mask'),
             ('t1w_dseg', 'inputnode.t1w_dseg')]),
     ])
+    # fmt:on
 
     if existing_derivatives is not None:
-        LOGGER.log(25, "Anatomical workflow will reuse prior derivatives found in the "
-                   "output folder (%s).", output_dir)
+        LOGGER.log(
+            25,
+            "Anatomical workflow will reuse prior derivatives found in the "
+            "output folder (%s).",
+            output_dir,
+        )
         desc += """
 Anatomical preprocessing was reused from previously existing derivative objects.\n"""
         workflow.__desc__ = desc
 
-        templates = existing_derivatives.pop('template')
-        templatesource = pe.Node(niu.IdentityInterface(
-            fields=['template']), name='templatesource')
-        templatesource.iterables = [('template', templates)]
+        templates = existing_derivatives.pop("template")
+        templatesource = pe.Node(
+            niu.IdentityInterface(fields=["template"]), name="templatesource"
+        )
+        templatesource.iterables = [("template", templates)]
         outputnode.inputs.template = templates
 
         for field, value in existing_derivatives.items():
             setattr(outputnode.inputs, field, value)
 
-        anat_reports_wf.inputs.inputnode.source_file = [existing_derivatives['t1w_preproc']]
+        anat_reports_wf.inputs.inputnode.source_file = [
+            existing_derivatives["t1w_preproc"]
+        ]
 
-        stdselect = pe.Node(KeySelect(
-            fields=['std_preproc', 'std_mask'], keys=templates),
-            name='stdselect', run_without_submitting=True)
+        stdselect = pe.Node(
+            KeySelect(fields=["std_preproc", "std_mask"], keys=templates),
+            name="stdselect",
+            run_without_submitting=True,
+        )
+        # fmt:off
         workflow.connect([
             (inputnode, outputnode, [('subjects_dir', 'subjects_dir'),
                                      ('subject_id', 'subject_id')]),
@@ -249,18 +290,27 @@ Anatomical preprocessing was reused from previously existing derivative objects.
                 ('std_mask', 'inputnode.std_mask'),
             ]),
         ])
+        # fmt:on
         return workflow
 
     # The workflow is not cached.
-    desc += """
+    desc += (
+        """
 All of them were corrected for intensity non-uniformity (INU)
-""" if num_t1w > 1 else """\
+"""
+        if num_t1w > 1
+        else """\
 The T1-weighted (T1w) image was corrected for intensity non-uniformity (INU)
 """
+    )
     desc += """\
 with `N4BiasFieldCorrection` [@n4], distributed with ANTs {ants_ver} \
 [@ants, RRID:SCR_004757]"""
-    desc += '.\n' if num_t1w > 1 else ", and used as T1w-reference throughout the workflow.\n"
+    desc += (
+        ".\n"
+        if num_t1w > 1
+        else ", and used as T1w-reference throughout the workflow.\n"
+    )
 
     desc += """\
 The T1w-reference was then skull-stripped with a *Nipype* implementation of
@@ -273,41 +323,50 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
 """
 
     workflow.__desc__ = desc.format(
-        ants_ver=ANTsInfo.version() or '(version unknown)',
-        fsl_ver=fsl.FAST().version or '(version unknown)',
+        ants_ver=ANTsInfo.version() or "(version unknown)",
+        fsl_ver=fsl.FAST().version or "(version unknown)",
         num_t1w=num_t1w,
         skullstrip_tpl=skull_strip_template.fullname,
     )
 
-    buffernode = pe.Node(niu.IdentityInterface(
-        fields=['t1w_brain', 't1w_mask']), name='buffernode')
+    buffernode = pe.Node(
+        niu.IdentityInterface(fields=["t1w_brain", "t1w_mask"]), name="buffernode"
+    )
 
     # 1. Anatomical reference generation - average input T1w images.
-    anat_template_wf = init_anat_template_wf(longitudinal=longitudinal, omp_nthreads=omp_nthreads,
-                                             num_t1w=num_t1w)
+    anat_template_wf = init_anat_template_wf(
+        longitudinal=longitudinal, omp_nthreads=omp_nthreads, num_t1w=num_t1w
+    )
 
-    anat_validate = pe.Node(ValidateImage(), name='anat_validate',
-                            run_without_submitting=True)
+    anat_validate = pe.Node(
+        ValidateImage(), name="anat_validate", run_without_submitting=True
+    )
 
     # 2. Brain-extraction and INU (bias field) correction.
-    if skull_strip_mode == 'auto':
+    if skull_strip_mode == "auto":
         import numpy as np
         import nibabel as nb
 
         def _is_skull_stripped(imgs):
             """Check if T1w images are skull-stripped."""
+
             def _check_img(img):
                 data = np.abs(nb.load(img).get_fdata(dtype=np.float32))
-                sidevals = data[0, :, :].sum() + data[-1, :, :].sum() + \
-                    data[:, 0, :].sum() + data[:, -1, :].sum() + \
-                    data[:, :, 0].sum() + data[:, :, -1].sum()
+                sidevals = (
+                    data[0, :, :].sum()
+                    + data[-1, :, :].sum()
+                    + data[:, 0, :].sum()
+                    + data[:, -1, :].sum()
+                    + data[:, :, 0].sum()
+                    + data[:, :, -1].sum()
+                )
                 return sidevals < 10
 
             return all(_check_img(img) for img in imgs)
 
         skull_strip_mode = _is_skull_stripped(t1w)
 
-    if skull_strip_mode in (True, 'skip'):
+    if skull_strip_mode in (True, "skip"):
         brain_extraction_wf = init_n4_only_wf(
             omp_nthreads=omp_nthreads,
             atropos_use_random_seed=not skull_strip_fixed_seed,
@@ -318,7 +377,8 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
             template_spec=skull_strip_template.spec,
             atropos_use_random_seed=not skull_strip_fixed_seed,
             omp_nthreads=omp_nthreads,
-            normalization_quality='precise' if not debug else 'testing')
+            normalization_quality="precise" if not debug else "testing",
+        )
 
     # 4. Spatial normalization
     anat_norm_wf = init_anat_norm_wf(
@@ -327,6 +387,7 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
         templates=spaces.get_spaces(nonstandard=False, dim=(3,)),
     )
 
+    # fmt:off
     workflow.connect([
         # Step 1.
         (inputnode, anat_template_wf, [('t1w', 'inputnode.t1w')]),
@@ -357,18 +418,21 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
             ('outputnode.std2anat_xfm', 'std2anat_xfm'),
         ]),
     ])
+    # fmt:on
 
     # Change LookUp Table - BIDS wants: 0 (bg), 1 (gm), 2 (wm), 3 (csf)
-    lut_t1w_dseg = pe.Node(niu.Function(function=_apply_bids_lut),
-                           name='lut_t1w_dseg')
+    lut_t1w_dseg = pe.Node(niu.Function(function=_apply_bids_lut), name="lut_t1w_dseg")
 
+    # fmt:off
     workflow.connect([
         (lut_t1w_dseg, anat_norm_wf, [
             ('out', 'inputnode.moving_segmentation')]),
         (lut_t1w_dseg, outputnode, [('out', 't1w_dseg')]),
     ])
+    # fmt:on
 
     # Connect reportlets
+    # fmt:off
     workflow.connect([
         (inputnode, anat_reports_wf, [('t1w', 'inputnode.source_file')]),
         (outputnode, anat_reports_wf, [
@@ -380,6 +444,7 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
         (anat_norm_wf, anat_reports_wf, [
             ('poutputnode.template', 'inputnode.template')]),
     ])
+    # fmt:on
 
     # Write outputs ############################################3
     anat_derivatives_wf = init_anat_derivatives_wf(
@@ -390,6 +455,7 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
         spaces=spaces,
     )
 
+    # fmt:off
     workflow.connect([
         # Connect derivatives
         (anat_template_wf, anat_derivatives_wf, [
@@ -407,13 +473,24 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
             ('t1w_tpms', 'inputnode.t1w_tpms'),
         ]),
     ])
+    # fmt:on
+
+    # XXX Keeping FAST separate so that it's easier to swap in ANTs or FreeSurfer
 
     # Brain tissue segmentation - FAST produces: 0 (bg), 1 (wm), 2 (csf), 3 (gm)
-    t1w_dseg = pe.Node(fsl.FAST(segments=True, no_bias=True, probability_maps=True),
-                       name='t1w_dseg', mem_gb=3)
+    t1w_dseg = pe.Node(
+        fsl.FAST(segments=True, no_bias=True, probability_maps=True),
+        name="t1w_dseg",
+        mem_gb=3,
+    )
     lut_t1w_dseg.inputs.lut = (0, 3, 1, 2)  # Maps: 0 -> 0, 3 -> 1, 1 -> 2, 2 -> 3.
-    fast2bids = pe.Node(niu.Function(function=_probseg_fast2bids), name="fast2bids",
-                        run_without_submitting=True)
+    fast2bids = pe.Node(
+        niu.Function(function=_probseg_fast2bids),
+        name="fast2bids",
+        run_without_submitting=True,
+    )
+
+    # fmt:off
     workflow.connect([
         (buffernode, t1w_dseg, [('t1w_brain', 'in_files')]),
         (t1w_dseg, lut_t1w_dseg, [('partial_volume_map', 'in_dseg')]),
@@ -421,8 +498,9 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
         (fast2bids, anat_norm_wf, [('out', 'inputnode.moving_tpms')]),
         (fast2bids, outputnode, [('out', 't1w_tpms')]),
     ])
-
+    # fmt:on
     if not freesurfer:  # Flag --fs-no-reconall is set - return
+        # fmt:off
         workflow.connect([
             (brain_extraction_wf, buffernode, [
                 (('outputnode.out_file', _pop), 't1w_brain'),
@@ -431,14 +509,17 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
         return workflow
 
     # check for older IsRunning files and remove accordingly
-    fs_isrunning = pe.Node(niu.Function(function=_fs_isRunning),
-                           overwrite=True, name='fs_isrunning')
+    fs_isrunning = pe.Node(
+        niu.Function(function=_fs_isRunning), overwrite=True, name="fs_isrunning"
+    )
     fs_isrunning.inputs.logger = LOGGER
 
     # 5. Surface reconstruction (--fs-no-reconall not set)
-    surface_recon_wf = init_surface_recon_wf(name='surface_recon_wf',
-                                             omp_nthreads=omp_nthreads, hires=hires)
-    applyrefined = pe.Node(fsl.ApplyMask(), name='applyrefined')
+    surface_recon_wf = init_surface_recon_wf(
+        name="surface_recon_wf", omp_nthreads=omp_nthreads, hires=hires
+    )
+    applyrefined = pe.Node(fsl.ApplyMask(), name="applyrefined")
+    # fmt:off
     workflow.connect([
         (inputnode, fs_isrunning, [
             ('subjects_dir', 'subjects_dir'),
@@ -481,11 +562,14 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
             ('surfaces', 'inputnode.surfaces'),
         ]),
     ])
+    # fmt:on
 
     return workflow
 
 
-def init_anat_template_wf(*, longitudinal, omp_nthreads, num_t1w, name='anat_template_wf'):
+def init_anat_template_wf(
+    *, longitudinal, omp_nthreads, num_t1w, name="anat_template_wf"
+):
     """
     Generate a canonically-oriented, structural average from all input T1w images.
 
@@ -532,17 +616,23 @@ def init_anat_template_wf(*, longitudinal, omp_nthreads, num_t1w, name='anat_tem
 A T1w-reference map was computed after registration of
 {num_t1w} T1w images (after INU-correction) using
 `mri_robust_template` [FreeSurfer {fs_ver}, @fs_template].
-""".format(num_t1w=num_t1w, fs_ver=fs.Info().looseversion() or '<ver>')
+""".format(
+            num_t1w=num_t1w, fs_ver=fs.Info().looseversion() or "<ver>"
+        )
 
-    inputnode = pe.Node(niu.IdentityInterface(fields=['t1w']), name='inputnode')
-    outputnode = pe.Node(niu.IdentityInterface(
-        fields=['t1w_ref', 't1w_valid_list', 't1w_realign_xfm', 'out_report']),
-        name='outputnode')
+    inputnode = pe.Node(niu.IdentityInterface(fields=["t1w"]), name="inputnode")
+    outputnode = pe.Node(
+        niu.IdentityInterface(
+            fields=["t1w_ref", "t1w_valid_list", "t1w_realign_xfm", "out_report"]
+        ),
+        name="outputnode",
+    )
 
     # 0. Reorient T1w image(s) to RAS and resample to common voxel space
-    t1w_ref_dimensions = pe.Node(TemplateDimensions(), name='t1w_ref_dimensions')
-    t1w_conform = pe.MapNode(Conform(), iterfield='in_file', name='t1w_conform')
+    t1w_ref_dimensions = pe.Node(TemplateDimensions(), name="t1w_ref_dimensions")
+    t1w_conform = pe.MapNode(Conform(), iterfield="in_file", name="t1w_conform")
 
+    # fmt:off
     workflow.connect([
         (inputnode, t1w_ref_dimensions, [('t1w', 't1w_list')]),
         (t1w_ref_dimensions, t1w_conform, [
@@ -552,21 +642,27 @@ A T1w-reference map was computed after registration of
         (t1w_ref_dimensions, outputnode, [('out_report', 'out_report'),
                                           ('t1w_valid_list', 't1w_valid_list')]),
     ])
+    # fmt:on
 
     if num_t1w == 1:
-        get1st = pe.Node(niu.Select(index=[0]), name='get1st')
-        outputnode.inputs.t1w_realign_xfm = [pkgr('smriprep', 'data/itkIdentityTransform.txt')]
+        get1st = pe.Node(niu.Select(index=[0]), name="get1st")
+        outputnode.inputs.t1w_realign_xfm = [
+            pkgr("smriprep", "data/itkIdentityTransform.txt")
+        ]
 
+        # fmt:off
         workflow.connect([
             (t1w_conform, get1st, [('out_file', 'inlist')]),
             (get1st, outputnode, [('out', 't1w_ref')]),
         ])
-
+        # fmt:on
         return workflow
 
-    t1w_conform_xfm = pe.MapNode(LTAConvert(in_lta='identity.nofile', out_lta=True),
-                                 iterfield=['source_file', 'target_file'],
-                                 name='t1w_conform_xfm')
+    t1w_conform_xfm = pe.MapNode(
+        LTAConvert(in_lta="identity.nofile", out_lta=True),
+        iterfield=["source_file", "target_file"],
+        name="t1w_conform_xfm",
+    )
 
     # 1. Template (only if several T1w images)
     # 1a. Correct for bias field: the bias field is an additive factor
@@ -575,32 +671,45 @@ A T1w-reference map was computed after registration of
     # 1b. Align and merge if several T1w images are provided
     n4_correct = pe.MapNode(
         N4BiasFieldCorrection(dimension=3, copy_header=True),
-        iterfield='input_image', name='n4_correct',
-        n_procs=1)  # n_procs=1 for reproducibility
+        iterfield="input_image",
+        name="n4_correct",
+        n_procs=1,
+    )  # n_procs=1 for reproducibility
     # StructuralReference is fs.RobustTemplate if > 1 volume, copying otherwise
     t1w_merge = pe.Node(
-        StructuralReference(auto_detect_sensitivity=True,
-                            initial_timepoint=1,      # For deterministic behavior
-                            intensity_scaling=True,   # 7-DOF (rigid + intensity)
-                            subsample_threshold=200,
-                            fixed_timepoint=not longitudinal,
-                            no_iteration=not longitudinal,
-                            transform_outputs=True,
-                            ),
+        StructuralReference(
+            auto_detect_sensitivity=True,
+            initial_timepoint=1,  # For deterministic behavior
+            intensity_scaling=True,  # 7-DOF (rigid + intensity)
+            subsample_threshold=200,
+            fixed_timepoint=not longitudinal,
+            no_iteration=not longitudinal,
+            transform_outputs=True,
+        ),
         mem_gb=2 * num_t1w - 1,
-        name='t1w_merge')
+        name="t1w_merge",
+    )
 
     # 2. Reorient template to RAS, if needed (mri_robust_template may set to LIA)
-    t1w_reorient = pe.Node(image.Reorient(), name='t1w_reorient')
+    t1w_reorient = pe.Node(image.Reorient(), name="t1w_reorient")
 
-    merge_xfm = pe.MapNode(niu.Merge(2), name='merge_xfm',
-                           iterfield=['in1', 'in2'], run_without_submitting=True)
-    concat_xfms = pe.MapNode(ConcatenateXFMs(inverse=True), name="concat_xfms",
-                             iterfield=['in_xfms'], run_without_submitting=True)
+    merge_xfm = pe.MapNode(
+        niu.Merge(2),
+        name="merge_xfm",
+        iterfield=["in1", "in2"],
+        run_without_submitting=True,
+    )
+    concat_xfms = pe.MapNode(
+        ConcatenateXFMs(inverse=True),
+        name="concat_xfms",
+        iterfield=["in_xfms"],
+        run_without_submitting=True,
+    )
 
     def _set_threads(in_list, maximum):
         return min(len(in_list), maximum)
 
+    # fmt:off
     workflow.connect([
         (t1w_ref_dimensions, t1w_conform_xfm, [('t1w_valid_list', 'source_file')]),
         (t1w_conform, t1w_conform_xfm, [('out_file', 'target_file')]),
@@ -618,7 +727,7 @@ A T1w-reference map was computed after registration of
         (t1w_reorient, outputnode, [('out_file', 't1w_ref')]),
         (concat_xfms, outputnode, [('out_xfm', 't1w_realign_xfm')]),
     ])
-
+    # fmt:on
     return workflow
 
 
@@ -642,6 +751,7 @@ def _aseg_to_three():
 
     """
     import numpy as np
+
     # Base struct
     aseg_lut = np.zeros((256,), dtype="int")
     # GM
@@ -680,7 +790,7 @@ def _split_segments(in_file):
     segimg = nb.load(in_file)
     data = np.int16(segimg.dataobj)
     hdr = segimg.header.copy()
-    hdr.set_data_dtype('uint8')
+    hdr.set_data_dtype("uint8")
 
     out_files = []
     for i, label in enumerate(("GM", "WM", "CSF"), 1):
